@@ -93,11 +93,11 @@
     </message>
     <message>
         <source>Unknown Windows OS</source>
-        <translation>Neznámé Windows OS</translation>
+        <translation type="vanished">Neznámé Windows OS</translation>
     </message>
     <message>
         <source>Unknown Mac OS</source>
-        <translation>Neznámé Mac OS</translation>
+        <translation type="vanished">Neznámé Mac OS</translation>
     </message>
     <message>
         <source>Czech</source>
@@ -775,6 +775,18 @@ rozhodnete pro přehrání, přehrána bez zvuku.</translation>
         <source>Choose image editor</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Style</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Information</source>
+        <translation type="unfinished">Informace</translation>
+    </message>
+    <message>
+        <source>Pease restart qStopMotion to activate the new style!</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>GrabberWidget</name>
@@ -792,7 +804,7 @@ rozhodnete pro přehrání, přehrána bez zvuku.</translation>
     </message>
     <message>
         <source>Pease restart qStopMotion to activate the changings!</source>
-        <translation>Pro zapnutí změn spusťte, prosím, qStopMotion znovu!</translation>
+        <translation type="vanished">Pro zapnutí změn spusťte, prosím, qStopMotion znovu!</translation>
     </message>
     <message>
         <source>GStreamer Video 4 Linux 2 Source</source>
@@ -822,6 +834,10 @@ rozhodnete pro přehrání, přehrána bez zvuku.</translation>
         <source>Camera Controller (Experimental)</source>
         <translation>Ovládací spínač kamery (pokusné)</translation>
     </message>
+    <message>
+        <source>Pease restart qStopMotion to activate the new grabber stettings!</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>GstreamerDv1394Grabber</name>
@@ -1447,6 +1463,10 @@ Kodér nainstalujte nebo vyberte jiný!</translation>
         <source>&lt;h4&gt;Support Us&lt;/h4&gt; &lt;p&gt;This button will bring up the browser with the qStopMotion support us page&lt;/p&gt;</source>
         <translation>&lt;h4&gt;Podpořte nás&lt;/h4&gt; &lt;p&gt;Tímto tlačítkem se vyvolá prohlížeč se stránkou k qStopMotion Podpořte nás&lt;/p&gt;</translation>
     </message>
+    <message>
+        <source>No style</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PreferencesTool</name>
